@@ -13,6 +13,7 @@ from typing import (
     DefaultDict,
     Dict,
     Iterator,
+    Mapping,
     Optional,
     Type,
     TypeVar,
@@ -73,14 +74,6 @@ def snooper_to_methods(  # type: ignore
     return inner
 
 
-def load_json_or_yaml(text: str) -> Dict[Any, Any]:
-    try:
-        data = json.loads(text)
-    except JSONDecodeError:
-        data = yaml.safe_load(text)
-    return data
-
-
 @contextlib.contextmanager
 def chdir(path: Optional[Path]) -> Iterator[None]:
     """Changes working directory and returns to previous on exit."""
@@ -97,7 +90,7 @@ def chdir(path: Optional[Path]) -> Iterator[None]:
 
 
 def is_openapi(text: str) -> bool:
-    return 'openapi' in load_json_or_yaml(text)
+    return 'openapi' in yaml.safe_load(text)
 
 
 class InputFileType(Enum):
@@ -127,6 +120,8 @@ def generate(
     extra_template_data: Optional[DefaultDict[str, Dict[str, Any]]] = None,
     validation: bool = False,
     field_constraints: bool = False,
+    snake_case_field: bool = False,
+    aliases: Optional[Mapping[str, str]] = None,
 ) -> None:
     if input_file_type == InputFileType.Auto:
         try:
@@ -175,6 +170,8 @@ def generate(
         dump_resolve_reference_action=dump_resolve_reference_action,
         validation=validation,
         field_constraints=field_constraints,
+        snake_case_field=snake_case_field,
+        aliases=aliases,
     )
 
     with chdir(output):
