@@ -9,6 +9,7 @@ from typing import (
     DefaultDict,
     Dict,
     List,
+    Mapping,
     Optional,
     Set,
     Tuple,
@@ -28,6 +29,9 @@ from ..types import DataType, DataTypePy36
 
 inflect_engine = inflect.engine()
 
+_UNDER_SCORE_1 = re.compile(r'(.)([A-Z][a-z]+)')
+_UNDER_SCORE_2 = re.compile('([a-z0-9])([A-Z])')
+
 
 def get_singular_name(name: str, suffix: str = 'Item') -> str:
     singular_name = inflect_engine.singular_noun(name)
@@ -45,6 +49,20 @@ def snake_to_upper_camel(word: str) -> str:
     return prefix + ''.join(x[0].upper() + x[1:] for x in word.split('_') if x)
 
 
+def camel_to_snake(string: str) -> str:
+    subbed = _UNDER_SCORE_1.sub(r'\1_\2', string)
+    return _UNDER_SCORE_2.sub(r'\1_\2', subbed).lower()
+
+
+def snakify_field(field: DataModelFieldBase) -> None:
+    if not field.name:
+        return
+    original_name = field.name
+    field.name = camel_to_snake(original_name)
+    if field.name != original_name:
+        field.alias = original_name
+
+
 def dump_templates(templates: Union[DataModel, List[DataModel]]) -> str:
     if isinstance(templates, TemplateBase):
         templates = [templates]
@@ -130,15 +148,19 @@ class Reference(BaseModel):
     path: List[str]
     original_name: str
     name: str
+    loaded: bool = True
 
 
 class ModelResolver:
-    def __init__(self) -> None:
+    def __init__(self, aliases: Optional[Mapping[str, str]] = None) -> None:
         self.references: Dict[str, Reference] = {}
+        self.aliases = {**aliases} if aliases is not None else {}
 
     @staticmethod
     def _get_path(path: List[str]) -> str:
-
+        if '#' in path:  # remote
+            delimiter = path.index('#')
+            return f"{''.join(path[:delimiter])}#/{''.join(path[delimiter + 1:])}"
         return '/'.join(path)
 
     def add_ref(self, ref: str) -> Reference:
@@ -148,7 +170,10 @@ class ModelResolver:
 
         name = self.get_class_name(original_name, unique=False)
         reference = Reference(
-            path=parents.split('/'), original_name=original_name, name=name
+            path=ref.split('/'),
+            original_name=original_name,
+            name=name,
+            loaded=not ref.startswith(('https://', 'http://')),
         )
         self.references[ref] = reference
         return reference
@@ -182,7 +207,11 @@ class ModelResolver:
         self.references[joined_path] = reference
         return reference
 
-    def get(self, path: List[str]) -> Reference:  # pragma: no cover
+    def get(
+        self, path: Union[List[str], str]
+    ) -> Optional[Reference]:  # pragma: no cover
+        if isinstance(path, str):
+            return self.references.get(path)
         return self.references[self._get_path(path)]
 
     def get_class_name(self, field_name: str, unique: bool = True) -> str:
@@ -225,6 +254,8 @@ class ModelResolver:
     def get_valid_field_name_and_alias(
         self, field_name: str
     ) -> Tuple[str, Optional[str]]:
+        if field_name in self.aliases:
+            return self.aliases[field_name], field_name
         valid_name = self.get_valid_name(field_name)
         return valid_name, None if field_name == valid_name else field_name
 
@@ -244,6 +275,8 @@ class Parser(ABC):
         dump_resolve_reference_action: Optional[Callable[[List[str]], str]] = None,
         validation: bool = False,
         field_constraints: bool = False,
+        snake_case_field: bool = False,
+        aliases: Optional[Mapping[str, str]] = None,
     ):
 
         self.data_model_type: Type[DataModel] = data_model_type
@@ -251,7 +284,6 @@ class Parser(ABC):
         self.data_model_field_type: Type[DataModelFieldBase] = data_model_field_type
         self.imports: Imports = Imports()
         self.base_class: Optional[str] = base_class
-        self.created_model_names: Set[str] = set()
         self.target_python_version: PythonVersion = target_python_version
         self.text: Optional[str] = text
         self.results: List[DataModel] = result or []
@@ -260,6 +292,7 @@ class Parser(ABC):
         ] = dump_resolve_reference_action
         self.validation: bool = validation
         self.field_constraints: bool = field_constraints
+        self.snake_case_field: bool = snake_case_field
 
         if self.target_python_version == PythonVersion.PY_36:
             self.data_type: Type[DataType] = DataTypePy36
@@ -270,7 +303,6 @@ class Parser(ABC):
         #     self.base_path: Path = Path(filename).absolute().parent
         # else:
         self.base_path = Path.cwd()
-        self.excludes_ref_path: Set[str] = set()
 
         self.custom_template_dir = (
             Path(custom_template_dir).expanduser().resolve()
@@ -281,10 +313,12 @@ class Parser(ABC):
             str, Any
         ] = extra_template_data or defaultdict(dict)
 
-        self.model_resolver = ModelResolver()
+        self.model_resolver = ModelResolver(aliases=aliases)
 
     def append_result(self, data_model: DataModel) -> None:
-        self.created_model_names.add(data_model.name)
+        if self.snake_case_field:
+            for field in data_model.fields:
+                snakify_field(field)
         self.results.append(data_model)
 
     @abstractmethod
